==> haskell-docopt-0.7.0.8-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 docopt
version:              0.7.0.8
visibility:           public
id:                   docopt-0.7.0.8-4m9tFBSAUzIDYyvEbwWPwK
key:                  docopt-0.7.0.8-4m9tFBSAUzIDYyvEbwWPwK
license:              MIT
copyright:            (c) 2013-2015 Ryan Artecona
maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               Ryan Artecona
homepage:             https://github.com/docopt/docopt.hs
synopsis:             A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.

category:             Console
abi:                  d0dde1257228c01b351f88b377324470
exposed:              True
exposed-modules:      System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules:
    System.Console.Docopt.ApplicativeParsec
    System.Console.Docopt.ParseUtils System.Console.Docopt.Types
    System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
    System.Console.Docopt.Public System.Console.Docopt.QQ
    System.Console.Docopt.QQ.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-docopt
hs-libraries:         HSdocopt-0.7.0.8-4m9tFBSAUzIDYyvEbwWPwK
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html:         /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-docopt-0.7.0.8-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-docopt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 docopt
version:              0.7.0.8
visibility:           public
id:                   docopt-0.7.0.8-2mtEK3FqrXJ8DaOS4VXBSc
key:                  docopt-0.7.0.8-2mtEK3FqrXJ8DaOS4VXBSc
license:              MIT
copyright:            (c) 2013-2015 Ryan Artecona
maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               Ryan Artecona
homepage:             https://github.com/docopt/docopt.hs
synopsis:             A command-line interface parser that will make you smile
description:
    Docopt parses command-line interface usage text that adheres to a familiar syntax, and from it builds a command-line argument parser that will ensure your program is invoked correctly with the available options specified in the usage text. This allows the developer to write a usage text and get an argument parser for free.

category:             Console
abi:                  807b7937f0218d933cd7edd2afacc866
exposed:              True
exposed-modules:      System.Console.Docopt System.Console.Docopt.NoTH
hidden-modules:
    System.Console.Docopt.ApplicativeParsec
    System.Console.Docopt.ParseUtils System.Console.Docopt.Types
    System.Console.Docopt.UsageParse System.Console.Docopt.OptParse
    System.Console.Docopt.Public System.Console.Docopt.QQ
    System.Console.Docopt.QQ.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/docopt-0.7.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-docopt
hs-libraries:         HSdocopt-0.7.0.8-2mtEK3FqrXJ8DaOS4VXBSc
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-docopt/html/docopt.haddock
haddock-html:         /usr/share/doc/haskell-docopt/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
